(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    218891,       6102]
NotebookOptionsPosition[    210126,       5798]
NotebookOutlinePosition[    210475,       5813]
CellTagsIndexPosition[    210432,       5810]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["1. Quantitative analysis for China and the US", "Section",
 CellChangeTimes->{{3.7088548762038*^9, 3.7088549187665997`*^9}, {
  3.7088627861809998`*^9, 3.7088627868050003`*^9}, {3.7088630496448*^9, 
  3.708863090395*^9}, {3.7088631455626*^9, 3.7088631531754*^9}, {
  3.7314488515382*^9, 3.731448862817*^9}}],

Cell[CellGroupData[{

Cell["1. Benchmark ", "Subsection",
 CellChangeTimes->{{3.7088626085408*^9, 3.708862619882*^9}, {
  3.7088628987818003`*^9, 3.7088629005290003`*^9}, {3.7088629535875998`*^9, 
  3.7088629704512*^9}, {3.7314488823014*^9, 3.7314489407390003`*^9}, {
  3.7314490045744*^9, 3.7314490176004*^9}, {3.7314517212153997`*^9, 
  3.7314517217146*^9}}],

Cell[CellGroupData[{

Cell["Parameters:", "Subsubsection",
 CellChangeTimes->{{3.7088629766443996`*^9, 3.7088629804664*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.06", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.03", ",", "0.5", ",", "0.5"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7088551443768*^9, 3.7088551837668*^9}, {
  3.7088552198808002`*^9, 3.7088552225016003`*^9}, {3.7088553179892*^9, 
  3.7088553524068003`*^9}, {3.7088557126692*^9, 3.7088557221862*^9}, {
  3.7088574414982*^9, 3.7088574417946*^9}, {3.708857576959*^9, 
  3.7088575777390003`*^9}, {3.7314490670002003`*^9, 3.7314490736926003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.06`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.03`", ",", "0.5`", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.731449076719*^9, 3.7314510290122004`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calibration:", "Subsubsection",
 CellChangeTimes->{{3.7088632394358*^9, 3.7088632452390003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]n", "\[Equal]", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           RowBox[{"\[Sigma]", "-", "1"}]], "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"0.01823", "==", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      SuperscriptBox["z", 
       RowBox[{"\[Sigma]", "-", "1"}]]}], ",", 
     RowBox[{"in", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]n", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{"is", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]s", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Zeta]", ",", "0.8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]", ",", "1.2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"is", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7088555959634*^9, {3.7088556455754004`*^9, 3.7088556496001997`*^9}, {
   3.7088557315306*^9, 3.7088557349625998`*^9}, {3.7088557741352*^9, 
   3.7088557832476*^9}, {3.7088558446698*^9, 3.7088558472125998`*^9}, {
   3.7088559995369997`*^9, 3.7088560024074*^9}, {3.708856040097*^9, 
   3.7088560748382*^9}, {3.7088561223557997`*^9, 3.7088561950674*^9}, {
   3.7088562892602*^9, 3.7088563484652*^9}, 3.708856452881*^9, {
   3.7088564887142*^9, 3.7088566195334*^9}, {3.7088569249969997`*^9, 
   3.7088569969306*^9}, {3.7088573593592*^9, 3.7088573660360003`*^9}, {
   3.7088576045452003`*^9, 3.7088576127664003`*^9}, 3.7088645294208*^9, 
   3.7314491005402*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Zeta]", "\[Rule]", "0.8479550336243143`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "6.195218006549213`"}], ",", 
   RowBox[{"\[Lambda]", "\[Rule]", "2.578480404323203`"}], ",", 
   RowBox[{"in", "\[Rule]", "0.09088610999999999`"}], ",", 
   RowBox[{"is", "\[Rule]", "0.09758293`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7088571007098*^9, {3.7088573622764*^9, 3.7088573680952*^9}, 
   3.7088576282104*^9, 3.708863497748*^9, 3.708868020887*^9, 
   3.7314491033794003`*^9, 3.7314510327562*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Zeta]", ",", "\[Sigma]", ",", "\[Lambda]", ",", "in", ",", "is"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8479550336243143`", ",", "6.195218006549213`", ",", 
    "2.578480404323203`", ",", "0.09088610999999999`", ",", "0.09758293`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8479550336243143`", ",", "6.195218006549213`", ",", "2.578480404323203`",
    ",", "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314491160466003`*^9, 3.7314510351898003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.026", "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Psi]n", " ", "\[Gamma]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"\[Gamma]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                RowBox[{"(", 
                 FractionBox["1", 
                  RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                RowBox[{"(", 
                 RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                  RowBox[{
                   RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
                   RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Gamma]", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                    "\[Psi]n"}], "+", 
                    RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                    SuperscriptBox[
                    RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "s"], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                    RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}], " "}]], 
                 ")"}]}], "+", "\[Psi]n"}], ")"}]}], ")"}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], "\[Gamma]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                   RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Gamma]", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                    "\[Psi]n"}], "+", 
                    RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                    SuperscriptBox[
                    RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "s"], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                    RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}], " "}]], 
                  ")"}]}], "+", "\[Psi]n"}], ")"}]}], ")"}]}], ")"}], " ", 
          RowBox[{"(", 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                RowBox[{"\[Gamma]", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                 "\[Psi]n"}], "+", 
                RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                 SuperscriptBox[
                  RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"1", "-", "s"}], "s"], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}]}]], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{"0.013", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
              RowBox[{"(", 
               RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
              "\[Psi]n"}], "+", 
             RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
              SuperscriptBox[
               RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               FractionBox[
                RowBox[{"1", "-", "s"}], "s"], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                   "+", 
                   FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                  ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                   RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                   FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                   RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
                 "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
             RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}], ")"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox[
               RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
               RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], 
             "-", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"1", "-", "\[Beta]f"}], 
             RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
           FractionBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
           RowBox[{"(", 
            FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", "s"}], "s"], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"\[Gamma]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                RowBox[{"(", 
                 FractionBox["1", 
                  RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                RowBox[{"(", 
                 RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                  RowBox[{
                   RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
                   RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Gamma]", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                    "\[Psi]n"}], "+", 
                    RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                    SuperscriptBox[
                    RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "s"], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                    RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}], " "}]], 
                 ")"}]}], "+", "\[Psi]n"}], ")"}]}], ")"}]}], ")"}], " ", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{
               RowBox[{"\[Gamma]", 
                RowBox[{"(", 
                 RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                RowBox[{"(", 
                 FractionBox["1", 
                  RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                RowBox[{"(", 
                 RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                "\[Psi]n"}], "+", 
               RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                SuperscriptBox[
                 RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{"1", "-", "s"}], "s"], ")"}], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                   RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                   RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
                   "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
               RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}]}]], ")"}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox[
                   RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                   RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                   "\[Sigma]"]}], "-", 
                 RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
               RowBox[{"(", 
                FractionBox[
                 RowBox[{"1", "-", "\[Beta]f"}], 
                 RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
               RowBox[{"(", 
                FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}], "+", 
            RowBox[{"\[Omega]", 
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"1", "-", "s"}], "s"], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                   RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Gamma]", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                    "\[Psi]n"}], "+", 
                    RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                    SuperscriptBox[
                    RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "s"], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                    RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}], " "}]], 
                  ")"}]}], "+", "\[Psi]n"}], ")"}]}], ")"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                RowBox[{"\[Gamma]", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                 "\[Psi]n"}], "+", 
                RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                 SuperscriptBox[
                  RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"1", "-", "s"}], "s"], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}]}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                RowBox[{"\[Gamma]", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                 "\[Psi]n"}], "+", 
                RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                 SuperscriptBox[
                  RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"1", "-", "s"}], "s"], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}]}]], ")"}]}]}], 
        ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]n", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]f", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Beta]n", "\[Rule]", "0.7781244658361336`"}], ",", 
   RowBox[{"\[Beta]f", "\[Rule]", "0.5600974178408754`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314491432374*^9, 3.7314510443782*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{"0.7781244658361336`", ",", "0.5600974178408754`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.7781244658361336`", ",", "0.5600974178408754`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7314491758882*^9, 3.731451046453*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "xn", ",", "\[Psi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", "\[Beta]f"}], 
       RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
     FractionBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
     RowBox[{"(", 
      FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", 
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                RowBox[{"\[Gamma]", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                 RowBox[{"(", 
                  FractionBox["1", 
                   RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
                 "\[Psi]n"}], "+", 
                RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
                 SuperscriptBox[
                  RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  FractionBox[
                   RowBox[{"1", "-", "s"}], "s"], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["\[Phi]", 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    FractionBox["\[Sigma]", 
                    RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
                    RowBox[{
                    RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", 
                    "\[Phi]"}]]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
                    "\[Omega]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    FractionBox["1", 
                    RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                    RowBox[{"(", 
                    FractionBox[
                    RowBox[{"1", "-", "\[Beta]f"}], 
                    RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                    RowBox[{"(", 
                    FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], 
                    "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
                RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}]], ")"}], " "}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Gamma]", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Lambda]", " ", 
        "\[Psi]n"}], "+", 
       RowBox[{"\[Lambda]", " ", "\[Gamma]", " ", 
        SuperscriptBox[
         RowBox[{"(", "\[Psi]n", ")"}], "2"]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", "s"}], "s"], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["\[Phi]", 
               RowBox[{
                RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["\[Sigma]", 
                 RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Phi]"}]]}],
             ")"}], 
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
              "\[Omega]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FractionBox[
                    RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                    RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
                    "\[Sigma]"]}], "-", 
                  RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{"1", "-", "\[Beta]f"}], 
                  RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
                RowBox[{"(", 
                 FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}]}]}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
                 RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}],
                "-", 
               RowBox[{"\[Delta]", " ", "\[Omega]"}]}], ")"}], 
             RowBox[{"(", 
              FractionBox[
               RowBox[{"1", "-", "\[Beta]f"}], 
               RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Xi]f", " ", "is"}]}], ")"}]], 
             RowBox[{"(", 
              FractionBox["\[Gamma]", "\[Delta]"], ")"}]}], ")"}], " ", 
           "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}], "-", 
       RowBox[{"\[Gamma]", " ", "\[Psi]n"}]}], ")"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.514170154576432`", ",", 
   "0.06630450721119682`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314491881654*^9, 3.7314510528646*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"\[Omega]", ",", "xn", ",", "\[Psi]f"}], "]"}]], "Input",
 CellChangeTimes->{{3.7314492642622004`*^9, 3.7314492739653997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulation:", "Subsubsection",
 CellChangeTimes->{{3.7314498337246*^9, 3.7314498394653997`*^9}, {
  3.7314513325102*^9, 3.7314513341794*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}], ")"}]], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}], " ", "\[Delta]"}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f", " "}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", " ", 
      RowBox[{"xn", 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["\[Sigma]", 
                RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Phi]"}]]}], 
           ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
             "\[Omega]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
           ")"}]}], "+", 
         RowBox[{"\[Alpha]", "  ", "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}]}],
      ",", 
     RowBox[{"r", "==", 
      RowBox[{"\[Rho]", "+", 
       FractionBox["gL", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}]}], ",", 
     RowBox[{"gc", "==", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"RSN", "==", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]", " ", "xn"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], "\[Gamma]", " ", "xn", " ", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"RSF", "==", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", "s"}], "s"], ")"}], "xn", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}], "+", 
           RowBox[{"\[Omega]", 
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", "s"}], "s"], ")"}], " ", "xn", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", "\[Psi]f"}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", "xn", ")"}], 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Zeta]"}]]]}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], "+", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
          RowBox[{"(", 
           FractionBox["\[Psi]f", 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"iin0", "==", 
      RowBox[{
      "\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]", " ", "xn"}]}], 
     ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", "\[Gamma]", 
       " ", "xn"}]}], ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", "\[Alpha]", 
       " ", "xn", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Psi]f"}]], 
        ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xn", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.492537`"}], ",", 
   RowBox[{"xn", "\[Rule]", "0.5141701545764318`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06630450721119682`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.06823`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.018229999999999996`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.025999999999999992`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.013000000000000003`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.38039073231190385`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.06925592532410867`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.1965564622939329`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.08204527715901806`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.0014019277568265173`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.11310925737808823`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.0268501483034087`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.006692094370081574`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.0007105766425608322`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.019447477290766225`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "0.45515898894453005`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.07111545718995078`"}], ",", 
   RowBox[{"Un", "\[Rule]", 
    RowBox[{"-", "7.725557391270061`"}]}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "59.8699975677841`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314510658282003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Omega]n01", ",", "\[Omega]s01", ",", "In01", ",", "ain01", ",", "iin01",
     ",", "RDn01", ",", "Is01", ",", "ais01", ",", "iis01", ",", "RDs01", ",",
     "cn01", ",", "cs01", ",", "Un1", ",", "Us1"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.38039073231190385`", ",", "0.06925592532410867`", ",", 
    "1.1965564622939329`", ",", "0.08204527715901806`", ",", 
    "0.0014019277568265173`", ",", "0.11310925737808823`", ",", 
    "1.0268501483034087`", ",", "0.006692094370081574`", ",", 
    "0.0007105766425608322`", ",", "0.019447477290766225`", ",", 
    "0.45515898894453005`", ",", "0.07111545718995078`", ",", 
    RowBox[{"-", "7.725557391270061`"}], ",", 
    RowBox[{"-", "59.8699975677841`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.38039073231190385`", ",", "0.06925592532410867`", ",", 
   "1.1965564622939329`", ",", "0.08204527715901806`", ",", 
   "0.0014019277568265173`", ",", "0.11310925737808823`", ",", 
   "1.0268501483034087`", ",", "0.006692094370081574`", ",", 
   "0.0007105766425608322`", ",", "0.019447477290766225`", ",", 
   "0.45515898894453005`", ",", "0.07111545718995078`", ",", 
   RowBox[{"-", "7.725557391270061`"}], ",", 
   RowBox[{"-", "59.8699975677841`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314510856558*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The effects of monetary policy:", "Subsubsection",
 CellChangeTimes->{{3.7314515218786*^9, 3.7314515443894*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "in", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "in", "}"}], "=", 
  RowBox[{"{", "0", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{3.7314499108666*^9, 3.7314511045006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}], ")"}]], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}], " ", "\[Delta]"}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f", " "}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", " ", 
      RowBox[{"xn", 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["\[Sigma]", 
                RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Phi]"}]]}], 
           ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
             "\[Omega]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
           ")"}]}], "+", 
         RowBox[{"\[Alpha]", "  ", "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}]}],
      ",", 
     RowBox[{"r", "==", 
      RowBox[{"\[Rho]", "+", 
       FractionBox["gL", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}]}], ",", 
     RowBox[{"gc", "==", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"RSN", "==", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]", " ", "xn"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], "\[Gamma]", " ", "xn", " ", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"RSF", "==", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", "s"}], "s"], ")"}], "xn", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}], "+", 
           RowBox[{"\[Omega]", 
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", "s"}], "s"], ")"}], " ", "xn", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", "\[Psi]f"}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", "xn", ")"}], 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Zeta]"}]]]}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], "+", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
          RowBox[{"(", 
           FractionBox["\[Psi]f", 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"iin0", "==", 
      RowBox[{
      "\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]", " ", "xn"}]}], 
     ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", "\[Gamma]", 
       " ", "xn"}]}], ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", "\[Alpha]", 
       " ", "xn", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Psi]f"}]], 
        ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xn", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.5025701069051225`"}], ",", 
   RowBox[{"xn", "\[Rule]", "0.5351555511694768`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06561216045842262`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.06823`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.018229999999999996`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.02706669542632936`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.013432080394638583`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.4003563567482477`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.07275806558935874`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.194321119106381`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.08171267970482576`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.11260843940155522`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.0277411048100848`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.006914155155554367`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.0007341553906566627`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.02009279426387389`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "0.4781540520329207`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.07477645471265218`"}], ",", 
   RowBox[{"Un", "\[Rule]", 
    RowBox[{"-", "6.341114105059269`"}]}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "58.45993169768754`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.731451109087*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Omega]n0fn", ",", "\[Omega]s0fn", ",", "In0fn", ",", "ain0fn", ",", 
    "iin0fn", ",", "RDn0fn", ",", "Is0fn", ",", "ais0fn", ",", "iis0fn", ",", 
    "RDs0fn", ",", "cn0fn", ",", "cs0fn", ",", "Unfn", ",", "Usfn"}], "}"}], 
  "=", 
  RowBox[{"{", 
   RowBox[{
   "0.4003563567482477`", ",", "0.07275806558935874`", ",", 
    "1.194321119106381`", ",", "0.08171267970482576`", ",", "0.`", ",", 
    "0.11260843940155522`", ",", "1.0277411048100848`", ",", 
    "0.006914155155554367`", ",", "0.0007341553906566627`", ",", 
    "0.02009279426387389`", ",", "0.4781540520329207`", ",", 
    "0.07477645471265218`", ",", 
    RowBox[{"-", "6.341114105059269`"}], ",", 
    RowBox[{"-", "58.45993169768754`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.4003563567482477`", ",", "0.07275806558935874`", ",", 
   "1.194321119106381`", ",", "0.08171267970482576`", ",", "0.`", ",", 
   "0.11260843940155522`", ",", "1.0277411048100848`", ",", 
   "0.006914155155554367`", ",", "0.0007341553906566627`", ",", 
   "0.02009279426387389`", ",", "0.4781540520329207`", ",", 
   "0.07477645471265218`", ",", 
   RowBox[{"-", "6.341114105059269`"}], ",", 
   RowBox[{"-", "58.45993169768754`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314511221598*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[CapitalDelta]ln\[Omega]n0fn", ",", "\[CapitalDelta]ln\[Omega]ns0fn", 
    ",", "\[CapitalDelta]lnIn0fn", ",", "\[CapitalDelta]lnIs0fn", ",", 
    "\[CapitalDelta]lnain0fn", ",", "\[CapitalDelta]lnais0fn", ",", 
    "\[CapitalDelta]lniin0fn", ",", "\[CapitalDelta]lniis0fn", ",", 
    "\[CapitalDelta]lnRDn0fn", ",", "\[CapitalDelta]lnRDs0fn", ",", 
    "\[CapitalDelta]lncn0fn", ",", "\[CapitalDelta]lncs0fn"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]n0fn", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]n01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]s0fn", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]s01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "In0fn", "]"}], "-", 
       RowBox[{"Log", "[", "In01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "Is0fn", "]"}], "-", 
       RowBox[{"Log", "[", "Is01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ain0fn", "]"}], "-", 
       RowBox[{"Log", "[", "ain01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ais0fn", "]"}], "-", 
       RowBox[{"Log", "[", "ais01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iin0fn", "]"}], "-", 
       RowBox[{"Log", "[", "iin01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iis0fn", "]"}], "-", 
       RowBox[{"Log", "[", "iis01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDn0fn", "]"}], "-", 
       RowBox[{"Log", "[", "RDn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDs0fn", "]"}], "-", 
       RowBox[{"Log", "[", "RDs01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cn0fn", "]"}], "-", 
       RowBox[{"Log", "[", "cn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cs0fn", "]"}], "-", 
       RowBox[{"Log", "[", "cs01", "]"}]}], ")"}], "100"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.115607500313935`", ",", "4.933106145987454`", ",", 
   RowBox[{"-", "0.18698940140351727`"}], ",", "0.08672835155631962`", ",", 
   RowBox[{"-", "0.40620671861582025`"}], ",", "3.2643897077783812`", ",", 
   "Indeterminate", ",", "3.2643897077783812`", ",", 
   RowBox[{"-", "0.4437567860390512`"}], ",", "3.2643897077783812`", ",", 
   "4.92861809891042`", ",", "5.019834497543796`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314511629694*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "in", "}"}], "=", 
  RowBox[{"{", "0.09088610999999999`", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0.09088610999999999`", "}"}]], "Output",
 CellChangeTimes->{3.7314501016858*^9, 3.7314511926094*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "is", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "is", "}"}], "=", 
  RowBox[{"{", "0", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{3.7314501193606*^9, 3.7314511964314003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"\[Rho]", "+", "\[Psi]n"}], 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}], ")"}]], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}], " ", "\[Delta]"}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f", " "}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", " ", 
      RowBox[{"xn", 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["\[Sigma]", 
                RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Phi]"}]]}], 
           ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", 
             "\[Omega]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              FractionBox["1", 
               RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
           ")"}]}], "+", 
         RowBox[{"\[Alpha]", "  ", "\[Lambda]", " ", "\[Psi]n"}]}], ")"}]}]}],
      ",", 
     RowBox[{"r", "==", 
      RowBox[{"\[Rho]", "+", 
       FractionBox["gL", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}]}], ",", 
     RowBox[{"gc", "==", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"RSN", "==", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]", " ", "xn"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], "\[Gamma]", " ", "xn", " ", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"RSF", "==", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", "s"}], "s"], ")"}], "xn", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}], "+", 
           RowBox[{"\[Omega]", 
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", "s"}], "s"], ")"}], " ", "xn", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{" ", "\[Psi]f"}], 
           RowBox[{
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
          ")"}]}]}]]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["\[Phi]", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
            RowBox[{"(", 
             FractionBox["\[Psi]f", 
              RowBox[{
               RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
             RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", "xn", ")"}], 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Zeta]"}]]]}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]", " ", "xn", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], "+", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
          RowBox[{"(", 
           FractionBox["\[Psi]f", 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"iin0", "==", 
      RowBox[{
      "\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]", " ", "xn"}]}], 
     ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", "\[Gamma]", 
       " ", "xn"}]}], ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Psi]f", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]", " ", "xn", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", "\[Alpha]", 
       " ", "xn", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "\[Psi]n"}], " ", "+", "\[Psi]f"}]], 
        ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "s"}], "s"], ")"}]}]}], ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xn", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.482151639283599`"}], ",", 
   RowBox[{"xn", "\[Rule]", "0.5159235473420741`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06708226981428991`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.06823`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.018229999999999996`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.026089108915215917`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.013151306845637954`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.38183794080846756`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.0696511088953325`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.1971922443509553`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.08229055991962361`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.0014067085282596587`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.11349497590307206`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.0252131364068673`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.006454914043339856`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.01875822236352738`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "0.45713342133483653`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.07140723180480009`"}], ",", 
   RowBox[{"Un", "\[Rule]", 
    RowBox[{"-", "7.603969904699699`"}]}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "59.75498531738061`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.731451202141*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Omega]n0fs", ",", "\[Omega]s0fs", ",", "In0fs", ",", "ain0fs", ",", 
    "iin0fs", ",", "RDn0fs", ",", "Is0fs", ",", "ais0fs", ",", "iis0fs", ",", 
    "RDs0fs", ",", "cn0fs", ",", "cs0fs", ",", "Unfs", ",", "Usfs"}], "}"}], 
  "=", 
  RowBox[{"{", 
   RowBox[{
   "0.38183794080846756`", ",", "0.0696511088953325`", ",", 
    "1.1971922443509553`", ",", "0.08229055991962361`", ",", 
    "0.0014067085282596587`", ",", "0.11349497590307206`", ",", 
    "1.0252131364068673`", ",", "0.006454914043339856`", ",", "0.`", ",", 
    "0.01875822236352738`", ",", "0.45713342133483653`", ",", 
    "0.07140723180480009`", ",", 
    RowBox[{"-", "7.603969904699699`"}], ",", 
    RowBox[{"-", "59.75498531738061`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.38183794080846756`", ",", "0.0696511088953325`", ",", 
   "1.1971922443509553`", ",", "0.08229055991962361`", ",", 
   "0.0014067085282596587`", ",", "0.11349497590307206`", ",", 
   "1.0252131364068673`", ",", "0.006454914043339856`", ",", "0.`", ",", 
   "0.01875822236352738`", ",", "0.45713342133483653`", ",", 
   "0.07140723180480009`", ",", 
   RowBox[{"-", "7.603969904699699`"}], ",", 
   RowBox[{"-", "59.75498531738061`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.731451235759*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[CapitalDelta]ln\[Omega]n0fs", ",", "\[CapitalDelta]ln\[Omega]ns0fs", 
    ",", "\[CapitalDelta]lnIn0fs", ",", "\[CapitalDelta]lnIs0fs", ",", 
    "\[CapitalDelta]lnain0fs", ",", "\[CapitalDelta]lnais0fs", ",", 
    "\[CapitalDelta]lniin0fs", ",", "\[CapitalDelta]lniis0fs", ",", 
    "\[CapitalDelta]lnRDn0fs", ",", "\[CapitalDelta]lnRDs0fs", ",", 
    "\[CapitalDelta]lncn0fs", ",", "\[CapitalDelta]lncs0fs"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]n0fs", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]n01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]s0fs", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]s01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "In0fs", "]"}], "-", 
       RowBox[{"Log", "[", "In01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "Is0fs", "]"}], "-", 
       RowBox[{"Log", "[", "Is01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ain0fs", "]"}], "-", 
       RowBox[{"Log", "[", "ain01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ais0fs", "]"}], "-", 
       RowBox[{"Log", "[", "ais01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iin0fs", "]"}], "-", 
       RowBox[{"Log", "[", "iin01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iis0fs", "]"}], "-", 
       RowBox[{"Log", "[", "iis01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDn0fs", "]"}], "-", 
       RowBox[{"Log", "[", "RDn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDs0fs", "]"}], "-", 
       RowBox[{"Log", "[", "RDs01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cn0fs", "]"}], "-", 
       RowBox[{"Log", "[", "cn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cs0fs", "]"}], "-", 
       RowBox[{"Log", "[", "cs01", "]"}]}], ")"}], "100"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.379731250374149`", ",", "0.5689915411711155`", ",", 
   "0.053120201816314605`", ",", 
   RowBox[{"-", "0.15954792973463944`"}], ",", "0.29851424632667545`", ",", 
   RowBox[{"-", "3.608517703139391`"}], ",", "0.3404339732964168`", ",", 
   "Indeterminate", ",", "0.34043397329637237`", ",", 
   RowBox[{"-", "3.608517703139391`"}], ",", "0.4328514521904858`", ",", 
   "0.40944361143648855`"}], "}"}]], "Output",
 CellChangeTimes->{3.731451244651*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314510189969997`*^9, 3.7314510223198*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Robustness check on the innovation-arrival rate", "Subsection",
 CellChangeTimes->{{3.7314519102406*^9, 3.7314519376654*^9}}],

Cell[CellGroupData[{

Cell["Parameters: (\[Psi]n=0.04)", "Subsubsection",
 CellChangeTimes->{{3.708859206382*^9, 3.708859220734*^9}, {
  3.7088592830612*^9, 3.7088592930296*^9}, {3.7088633935466003`*^9, 
  3.7088633959958*^9}, {3.7314519487882*^9, 3.7314519510346003`*^9}, {
  3.731452024807*^9, 3.7314520343854*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f", ",", "\[Sigma]"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.04", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.03", ",", "0.5", ",", "0.5", ",", "6.195218006549213`"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7088634118016*^9, 3.708863413034*^9}, 3.731452046491*^9}
  ],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.04`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.03`", ",", "0.5`", ",", "0.5`", ",", "6.195218006549213`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7088634154988003`*^9, 3.7088635086212*^9, 
  3.7088680272986*^9, 3.7314520495486*^9, 3.7314521728198*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]n", "\[Equal]", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           RowBox[{"\[Sigma]", "-", "1"}]], "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      SuperscriptBox["z", 
       RowBox[{"\[Sigma]", "-", "1"}]]}], ",", 
     RowBox[{"in", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]n", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{"is", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]s", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Zeta]", ",", "0.9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]", ",", "1.2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"is", ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Zeta]", "\[Rule]", "0.7719325504364716`"}], ",", 
   RowBox[{"\[Lambda]", "\[Rule]", "2.578480404323203`"}], ",", 
   RowBox[{"in", "\[Rule]", "0.08480944333333333`"}], ",", 
   RowBox[{"is", "\[Rule]", "0.09150626333333334`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314520595950003`*^9, 3.7314521751754*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Zeta]", ",", "\[Lambda]", ",", "in", ",", "is"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.7719325504364716`", ",", "2.5784804043232024`", ",", 
    "0.09088610999999999`", ",", "0.09758293`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7719325504364716`", ",", "2.5784804043232024`", ",", 
   "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314520690797997`*^9, 3.7314521785762*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.731452078705*^9, 3.731452180417*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314521844262*^9, 3.7314521854245996`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters: (\[Psi]n=0.08)", "Subsubsection",
 CellChangeTimes->{{3.7314521002798*^9, 3.7314521249746*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f", ",", "\[Sigma]"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.08", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.03", ",", "0.5", ",", "0.5", ",", "6.195218006549213`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.08`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.03`", ",", "0.5`", ",", "0.5`", ",", "6.195218006549213`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7314521369398003`*^9, 3.7314521906818*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]n", "\[Equal]", 
      FractionBox["gL", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           RowBox[{"\[Sigma]", "-", "1"}]], "-", "1"}], ")"}]}]]}], ",", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      SuperscriptBox["z", 
       RowBox[{"\[Sigma]", "-", "1"}]]}], ",", 
     RowBox[{"in", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]n", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{"is", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]s", "+", "\[Rho]", "+", 
        FractionBox["gL", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Zeta]"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Zeta]", ",", "0.9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]", ",", "1.2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"is", ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Zeta]", "\[Rule]", "0.8859662752182361`"}], ",", 
   RowBox[{"\[Lambda]", "\[Rule]", "2.578480404323203`"}], ",", 
   RowBox[{"in", "\[Rule]", "0.09696277666666667`"}], ",", 
   RowBox[{"is", "\[Rule]", "0.10365959666666667`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314521465338*^9, 3.7314521927878*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Zeta]", ",", "\[Lambda]", ",", "in", ",", "is"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8859662752182361`", ",", "2.5784804043232024`", ",", 
    "0.09088610999999999`", ",", "0.09758293`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8859662752182361`", ",", "2.5784804043232024`", ",", 
   "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314522021633997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.731452211929*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314522347518*^9, 3.7314522357658*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3. Robustness check on the imitation rate\n",
 StyleBox["    Parameters: (", "Subsubsection"],
 "\[Phi]",
 StyleBox["=0.07)", "Subsubsection"]
}], "Subsection",
 CellChangeTimes->{{3.7314554075480003`*^9, 3.7314555094004*^9}, {
  3.7314555532208*^9, 3.7314556352612*^9}, {3.7314559543124*^9, 
  3.7314559976647997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.06", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.07", ",", "0.5", ",", "0.5"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.06`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.07`", ",", "0.5`", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314556498784*^9, 3.7314560069156*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Zeta]", ",", "\[Sigma]", ",", "\[Lambda]", ",", "in", ",", "is"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8479550336243143`", ",", "6.195218006549213`", ",", 
    "2.578480404323203`", ",", "0.09088610999999999`", ",", "0.09758293`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8479550336243143`", ",", "6.195218006549213`", ",", "2.578480404323203`",
    ",", "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314556606112003`*^9, 3.7314560084756002`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314556693627996`*^9, 3.7314560102539997`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314560173052*^9, 3.7314560183036003`*^9}}],

Cell[CellGroupData[{

Cell["Parameters: (\[Phi]=0.11)", "Subsubsection",
 CellChangeTimes->{{3.73145567969*^9, 3.7314557074736*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.06", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.11", ",", "0.5", ",", "0.5"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.06`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.11`", ",", "0.5`", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314557240875998`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Zeta]", ",", "\[Sigma]", ",", "\[Lambda]", ",", "in", ",", "is"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8479550336243143`", ",", "6.195218006549213`", ",", 
    "2.578480404323203`", ",", "0.09088610999999999`", ",", "0.09758293`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8479550336243143`", ",", "6.195218006549213`", ",", "2.578480404323203`",
    ",", "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314557331356*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.731455741466*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314559124576*^9, 3.73145591369*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Robustness check on the CIA parameters", "Subsection",
 CellChangeTimes->{{3.7314557529944*^9, 3.7314557982656*^9}}],

Cell[CellGroupData[{

Cell["Parameters: (\[Xi]n=1)", "Subsubsection",
 CellChangeTimes->{{3.7314558288571997`*^9, 3.7314558707276*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.06", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.03", ",", "1", ",", "0.5"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.06`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.03`", ",", "1", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314558833792*^9, 3.7314560239508*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Zeta]", ",", "\[Sigma]", ",", "\[Lambda]", ",", "in", ",", "is"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8479550336243143`", ",", "6.195218006549213`", ",", 
    "2.578480404323203`", ",", "0.09088610999999999`", ",", "0.09758293`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8479550336243143`", ",", "6.195218006549213`", ",", "2.578480404323203`",
    ",", "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.731455892006*^9, 3.7314560256043997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314559003052*^9, 3.731456027258*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314560346056004`*^9, 3.7314560355727997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters: (\[Xi]f=1)", "Subsubsection",
 CellChangeTimes->{{3.73145604356*^9, 3.7314560651504*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Psi]n", ",", "\[Gamma]", 
    ",", "\[Omega]", ",", "\[Delta]", ",", "\[Pi]n", ",", "\[Pi]s", ",", 
    "\[Phi]", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "0.06", ",", "1", 
    ",", "5.492537", ",", "0.2", ",", "0.02265611", ",", "0.02935293", ",", 
    "0.03", ",", "0.5", ",", "1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "0.06`", ",", 
   "1", ",", "5.492537`", ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`",
    ",", "0.03`", ",", "0.5`", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.7314561236972*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Zeta]", ",", "\[Sigma]", ",", "\[Lambda]", ",", "in", ",", "is"}], 
   "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.8479550336243143`", ",", "6.195218006549213`", ",", 
    "2.578480404323203`", ",", "0.09088610999999999`", ",", "0.09758293`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8479550336243143`", ",", "6.195218006549213`", ",", "2.578480404323203`",
    ",", "0.09088610999999999`", ",", "0.09758293`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314561312320004`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
    "0.5600974178408754`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.0405332148794404`", ",", "0.7781244658361336`", ",", 
   "0.5600974178408754`"}], "}"}]], "Output",
 CellChangeTimes->{3.731456138876*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7314561405764*^9, 3.7314561414656*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "2. Alternative R&D specification",
 StyleBox["\n  ", "Subsection"],
 StyleBox["   ", "Subsubsection"],
 StyleBox[" Parameters:", "Subsection"]
}], "Section",
 CellChangeTimes->{{3.7314561634304*^9, 3.731456265392*^9}, {
  3.7314563007688*^9, 3.7314563032024*^9}, {3.7314569782276*^9, 
  3.7314569801464*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[Rho]", ",", "gL", ",", "s", ",", "z", ",", "\[Omega]", ",", "\[Delta]", 
    ",", "\[Pi]n", ",", "\[Pi]s", ",", "\[Xi]n", ",", "\[Xi]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.05", ",", "0.0144", ",", "0.832840", ",", "1.2", ",", "5.492537", ",", 
    "0.2", ",", "0.02265611", ",", "0.02935293", ",", "0.5", ",", "0.5"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.05`", ",", "0.0144`", ",", "0.83284`", ",", "1.2`", ",", "5.492537`", 
   ",", "0.2`", ",", "0.02265611`", ",", "0.02935293`", ",", "0.5`", ",", 
   "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314563100196*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Beta]n", ",", "\[Beta]f"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{"0.7781244658361336`", ",", "0.5600974178408754`"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.7781244658361336`", ",", "0.5600974178408754`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7314563185996*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Calibration:", "Subsection"]], "Subsubsection",
 CellChangeTimes->{{3.7088634530832*^9, 3.7088634568115997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"in", "\[Equal]", 
      RowBox[{"(", 
       RowBox[{"\[Pi]n", "+", "\[Rho]", "+", "0.01823"}], ")"}]}], ",", 
     RowBox[{"is", "==", 
      RowBox[{"(", 
       RowBox[{"\[Pi]s", "+", "\[Rho]", "+", "0.01823"}], ")"}]}], ",", 
     RowBox[{"0.01823", "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", "-", "1"}], 
         RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}], ",", 
     RowBox[{"\[Lambda]", "==", 
      SuperscriptBox["z", 
       RowBox[{"\[Sigma]", "-", "1"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}]], 
         ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{"\[Delta]", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["s", 
         RowBox[{"1", "-", "s"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["\[Psi]f", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Phi]", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["\[Sigma]", 
              RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
          FractionBox[
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
           RowBox[{"\[Phi]", "+", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
           "\[Gamma]", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], 
         ")"}]}], "+", 
       RowBox[{"\[Alpha]", " ", "\[Psi]f"}]}]}], ",", 
     RowBox[{"0.026", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}]]}], ",", 
     RowBox[{"0.013", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
            "\[Gamma]", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
          ")"}]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"is", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]n", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0.1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7088635552692003`*^9, 3.7088635560959997`*^9}, 
   3.7088645649616003`*^9, {3.7314563392384*^9, 3.7314563420931997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"in", "\[Rule]", "0.09088610999999999`"}], ",", 
   RowBox[{"is", "\[Rule]", "0.09758293`"}], ",", 
   RowBox[{"\[Psi]n", "\[Rule]", "0.057930647752717196`"}], ",", 
   RowBox[{"\[Lambda]", "\[Rule]", "2.7392790529444917`"}], ",", 
   RowBox[{"\[Alpha]", "\[Rule]", "0.29224151895052963`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "0.5594718736753528`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "6.5270193175977465`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06480672926472199`"}], ",", 
   RowBox[{"\[Phi]", "\[Rule]", "0.03327487090959861`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7088634695880003`*^9, 3.708863513582*^9, 
  3.708863558436*^9, 3.7088680313078003`*^9, 3.7314563458528*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "in", ",", "is", ",", "\[Lambda]", ",", "\[Alpha]", ",", "\[Gamma]", ",", 
    "\[Sigma]", ",", "\[Phi]"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.09088610999999999`", ",", "0.09758293`", ",", "2.7392790529444917`", 
    ",", "0.29224151895052963`", ",", "0.5594718736753528`", ",", 
    "6.5270193175977465`", ",", "0.03327487090959861`"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.09088610999999999`", ",", "0.09758293`", ",", "2.7392790529444917`", ",",
    "0.29224151895052963`", ",", "0.5594718736753528`", ",", 
   "6.5270193175977465`", ",", "0.03327487090959861`"}], "}"}]], "Output",
 CellChangeTimes->{3.7314563637928*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"\[Omega]", ",", "gc"}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Simulation:", "Subsection"]], "Subsubsection",
 CellChangeTimes->{{3.7314563853988*^9, 3.7314563888308*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"gc", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", "-", "1"}], 
         RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}]], 
         ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{"\[Delta]", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["s", 
         RowBox[{"1", "-", "s"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["\[Psi]f", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Phi]", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["\[Sigma]", 
              RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
          FractionBox[
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
           RowBox[{"\[Phi]", "+", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
           "\[Gamma]", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], 
         ")"}]}], "+", 
       RowBox[{"\[Alpha]", " ", "\[Psi]f"}]}]}], ",", 
     RowBox[{"RSN", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}]]}], ",", 
     RowBox[{"RSF", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
            "\[Gamma]", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
          ")"}]}]}]]}], ",", 
     RowBox[{"r", "\[Equal]", 
      RowBox[{"\[Rho]", "+", 
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Lambda]", "-", "1"}], 
          RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["\[Phi]", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], " ", ",", 
     RowBox[{"iin0", "==", 
      RowBox[{"\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]"}]}], ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", 
       "\[Gamma]"}]}], " ", ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]"}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", 
       "\[Alpha]"}]}], " ", ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]n", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.492537`"}], ",", 
   RowBox[{"\[Psi]n", "\[Rule]", "0.057930647752717175`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06480672926472188`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.06823`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.018229999999999993`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.025999999999999992`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.012999999999999977`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.8909911114729104`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.1622184996610693`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.214149741244697`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.09384674672405943`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.0014728352260883792`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.11883015929454935`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.0510187805541615`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.024804161345699297`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.0009240721433115749`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.025290547065150746`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "1.0817966274461595`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.1704946896971027`"}], ",", 
   RowBox[{"Un", "\[Rule]", "16.59274872462314`"}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "35.30821563285789`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314563993296003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "gc1", ",", "\[Omega]n01", ",", "\[Omega]s01", ",", "In01", ",", "ain01", 
    ",", "iin01", ",", "RDn01", ",", "Is01", ",", "ais01", ",", "iis01", ",", 
    "RDs01", ",", "cn01", ",", "cs01", ",", "Un1", ",", "Us1"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.018229999999999993`", ",", "0.8909911114729104`", ",", 
    "0.1622184996610693`", ",", "1.214149741244697`", ",", 
    "0.09384674672405943`", ",", "0.0014728352260883792`", ",", 
    "0.11883015929454935`", ",", "1.0510187805541615`", ",", 
    "0.024804161345699297`", ",", "0.0009240721433115749`", ",", 
    "0.025290547065150746`", ",", "1.0817966274461595`", ",", 
    "0.1704946896971027`", ",", "16.59274872462314`", ",", 
    RowBox[{"-", "35.30821563285789`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.018229999999999993`", ",", "0.8909911114729104`", ",", 
   "0.1622184996610693`", ",", "1.214149741244697`", ",", 
   "0.09384674672405943`", ",", "0.0014728352260883792`", ",", 
   "0.11883015929454935`", ",", "1.0510187805541615`", ",", 
   "0.024804161345699297`", ",", "0.0009240721433115749`", ",", 
   "0.025290547065150746`", ",", "1.0817966274461595`", ",", 
   "0.1704946896971027`", ",", "16.59274872462314`", ",", 
   RowBox[{"-", "35.30821563285789`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.73145640883*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The effects of monetary policy", "Subsection"]], \
"Subsubsection",
 CellChangeTimes->{{3.7314564311535997`*^9, 3.7314564419488*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "in", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "in", "}"}], "=", 
  RowBox[{"{", "0", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{3.7314564612771997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"gc", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", "-", "1"}], 
         RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}]], 
         ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{"\[Delta]", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["s", 
         RowBox[{"1", "-", "s"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["\[Psi]f", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Phi]", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["\[Sigma]", 
              RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
          FractionBox[
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
           RowBox[{"\[Phi]", "+", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
           "\[Gamma]", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], 
         ")"}]}], "+", 
       RowBox[{"\[Alpha]", " ", "\[Psi]f"}]}]}], ",", 
     RowBox[{"RSN", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}]]}], ",", 
     RowBox[{"RSF", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
            "\[Gamma]", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
          ")"}]}]}]]}], ",", 
     RowBox[{"r", "\[Equal]", 
      RowBox[{"\[Rho]", "+", 
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Lambda]", "-", "1"}], 
          RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["\[Phi]", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], " ", ",", 
     RowBox[{"iin0", "==", 
      RowBox[{"\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]"}]}], ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", 
       "\[Gamma]"}]}], " ", ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]"}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", 
       "\[Alpha]"}]}], " ", ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]n", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.489121263857966`"}], ",", 
   RowBox[{"\[Psi]n", "\[Rule]", "0.06250570680090195`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.07136742516019878`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.06966970988904567`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.019669709889045664`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.02803492793388541`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.014319395263195332`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.8903448934883498`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.16220171693976773`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.2124089766156765`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.08976744001045511`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.12264153660522133`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.053672612132977`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.024804161345699297`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.00101762039650276`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.0278508303907748`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "1.0794621411492036`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.17090750678037878`"}], ",", 
   RowBox[{"Un", "\[Rule]", "17.66805731273416`"}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "34.10429281275697`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314564709960003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "gcfn", ",", "\[Omega]n0fn", ",", "\[Omega]s0fn", ",", "In0fn", ",", 
    "ain0fn", ",", "iin0fn", ",", "RDn0fn", ",", "Is0fn", ",", "ais0fn", ",", 
    "iis0fn", ",", "RDs0fn", ",", "cn0fn", ",", "cs0fn", ",", "Unfn", ",", 
    "Usfn"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.019669709889045664`", ",", "0.8903448934883498`", ",", 
    "0.16220171693976773`", ",", "1.2124089766156765`", ",", 
    "0.08976744001045511`", ",", "0.`", ",", "0.12264153660522133`", ",", 
    "1.053672612132977`", ",", "0.024804161345699297`", ",", 
    "0.00101762039650276`", ",", "0.0278508303907748`", ",", 
    "1.0794621411492036`", ",", "0.17090750678037878`", ",", 
    "17.66805731273416`", ",", 
    RowBox[{"-", "34.10429281275697`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.019669709889045664`", ",", "0.8903448934883498`", ",", 
   "0.16220171693976773`", ",", "1.2124089766156765`", ",", 
   "0.08976744001045511`", ",", "0.`", ",", "0.12264153660522133`", ",", 
   "1.053672612132977`", ",", "0.024804161345699297`", ",", 
   "0.00101762039650276`", ",", "0.0278508303907748`", ",", 
   "1.0794621411492036`", ",", "0.17090750678037878`", ",", 
   "17.66805731273416`", ",", 
   RowBox[{"-", "34.10429281275697`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314564803403997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[CapitalDelta]gcfn", ",", "\[CapitalDelta]ln\[Omega]n0fn", ",", 
    "\[CapitalDelta]ln\[Omega]ns0fn", ",", "\[CapitalDelta]lnIn0fn", ",", 
    "\[CapitalDelta]lnIs0fn", ",", "\[CapitalDelta]lnain0fn", ",", 
    "\[CapitalDelta]lnais0fn", ",", "\[CapitalDelta]lniin0fn", ",", 
    "\[CapitalDelta]lniis0fn", ",", "\[CapitalDelta]lnRDn0fn", ",", 
    "\[CapitalDelta]lnRDs0fn", ",", "\[CapitalDelta]lncn0fn", ",", 
    "\[CapitalDelta]lncs0fn"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"gcfn", "-", "gc1"}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]n0fn", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]n01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]s0fn", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]s01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "In0fn", "]"}], "-", 
       RowBox[{"Log", "[", "In01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "Is0fn", "]"}], "-", 
       RowBox[{"Log", "[", "Is01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ain0fn", "]"}], "-", 
       RowBox[{"Log", "[", "ain01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ais0fn", "]"}], "-", 
       RowBox[{"Log", "[", "ais01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iin0fn", "]"}], "-", 
       RowBox[{"Log", "[", "iin01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iis0fn", "]"}], "-", 
       RowBox[{"Log", "[", "iis01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDn0fn", "]"}], "-", 
       RowBox[{"Log", "[", "RDn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDs0fn", "]"}], "-", 
       RowBox[{"Log", "[", "RDs01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cn0fn", "]"}], "-", 
       RowBox[{"Log", "[", "cn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cs0fn", "]"}], "-", 
       RowBox[{"Log", "[", "cs01", "]"}]}], ")"}], "100"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.1439709889045671`", ",", 
   RowBox[{"-", "0.07255430880069441`"}], ",", 
   RowBox[{"-", "0.010346285747764306`"}], ",", 
   RowBox[{"-", "0.14347601933775156`"}], ",", "0.25218262349340703`", ",", 
   RowBox[{"-", "4.444077164086835`"}], ",", "0.`", ",", "Indeterminate", ",",
    "9.64320903471938`", ",", "3.157052305611785`", ",", "9.64320903471938`", 
   ",", 
   RowBox[{"-", "0.21603032813846818`"}], ",", "0.24183633774563784`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7314564894664*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]Unfn", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Unfn"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Un1"}]}], "]"}], "-", 
     "1"}], ")"}], " ", "100"}]}]], "Input"],

Cell[BoxData["3.9023142548562095`"], "Output",
 CellChangeTimes->{3.7314565191532*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]Usfn", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Usfn"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Us1"}]}], "]"}], "-", 
     "1"}], ")"}], " ", "100"}]}]], "Input"],

Cell[BoxData["4.37913909488965`"], "Output",
 CellChangeTimes->{3.7314565277799997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "in", "}"}], "=", 
  RowBox[{"{", "0.09088610999999999`", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0.09088610999999999`", "}"}]], "Output",
 CellChangeTimes->{3.7314565375924*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "is", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "is", "}"}], "=", 
  RowBox[{"{", "0", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{3.7314565542064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"gc", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[Lambda]", "-", "1"}], 
         RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}]], 
         ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], "\[Sigma]"]}], "-", 
       RowBox[{"\[Delta]", " ", "\[Omega]"}]}], "\[Equal]", 
      RowBox[{"\[Delta]", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", "\[Beta]n"}], 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        FractionBox["s", 
         RowBox[{"1", "-", "s"}]], ")"}], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]f", " ", "is"}]}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Xi]n", " ", "in"}]}]], ")"}], 
       RowBox[{"(", 
        FractionBox["\[Alpha]", "\[Gamma]"], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{"\[Gamma]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
          RowBox[{"(", 
           RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
            RowBox[{
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], 
           ")"}]}], "+", "\[Psi]n"}], ")"}]}]}], ",", 
     RowBox[{"1", "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["\[Psi]f", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Phi]", 
            RowBox[{"\[Phi]", "+", 
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["\[Sigma]", 
              RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Sigma]"]}], "+", 
          FractionBox[
           RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
           RowBox[{"\[Phi]", "+", 
            RowBox[{"\[Lambda]", " ", "\[Psi]n"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
           "\[Gamma]", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], 
         ")"}]}], "+", 
       RowBox[{"\[Alpha]", " ", "\[Psi]f"}]}]}], ",", 
     RowBox[{"RSN", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]n", " ", "\[Gamma]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}]]}], ",", 
     RowBox[{"RSF", "\[Equal]", 
      FractionBox[
       RowBox[{"\[Psi]f", " ", "\[Alpha]"}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Rho]", "+", "\[Psi]n", "+", "\[Phi]", "-", "gL"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Omega]", " ", 
            "\[Gamma]", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", "s"}], "s"], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], 
          ")"}]}]}]]}], ",", 
     RowBox[{"r", "\[Equal]", 
      RowBox[{"\[Rho]", "+", 
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"\[Lambda]", "-", "1"}], 
          RowBox[{"\[Sigma]", "-", "1"}]], ")"}], "\[Psi]n"}]}]}], ",", 
     RowBox[{"\[Omega]n0", "==", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Lambda]", " ", "\[Psi]n"}], 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"\[Sigma]", "-", "1"}], "\[Sigma]"], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["\[Phi]", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Phi]"}]], ")"}], 
           RowBox[{"(", 
            FractionBox["\[Psi]f", 
             RowBox[{
              RowBox[{"\[Lambda]", " ", "\[Psi]n"}], "+", "\[Psi]f"}]], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Delta]", " ", "\[Omega]"}], ")"}], 
            RowBox[{"\[Sigma]", "-", "1"}]]}]}], ")"}], ")"}], 
       FractionBox["1", 
        RowBox[{"\[Sigma]", "-", "1"}]]]}], ",", 
     RowBox[{"cn0", "==", 
      RowBox[{"\[Omega]n0", " ", "In0"}]}], ",", 
     RowBox[{"In0", "\[Equal]", 
      RowBox[{"ain0", "+", "iin0", "+", "1", "+", "RDn0"}]}], ",", 
     RowBox[{"ain0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Gamma]"}]}], " ", ",", 
     RowBox[{"iin0", "==", 
      RowBox[{"\[Xi]n", " ", "in", " ", "\[Psi]n", " ", "\[Gamma]"}]}], ",", 
     RowBox[{"RDn0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]n", 
         RowBox[{"1", "-", "\[Beta]n"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]n", " ", "in"}]}], ")"}], "\[Psi]n", " ", 
       "\[Gamma]"}]}], " ", ",", 
     RowBox[{"\[Omega]s0", "==", 
      FractionBox["\[Omega]n0", "\[Omega]"]}], ",", 
     RowBox[{"cs0", "==", 
      RowBox[{"\[Omega]s0", " ", "Is0"}]}], ",", 
     RowBox[{"Is0", "\[Equal]", 
      RowBox[{"ais0", "+", "iis0", "+", "1", "+", "RDs0"}]}], ",", 
     RowBox[{"ais0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Rho]", "-", "gL"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Alpha]"}]}], ",", 
     RowBox[{"iis0", "==", 
      RowBox[{"\[Xi]f", " ", "is", " ", "\[Psi]f", " ", "\[Alpha]"}]}], ",", 
     RowBox[{"RDs0", "==", 
      RowBox[{
       RowBox[{"(", 
        FractionBox["\[Beta]f", 
         RowBox[{"1", "-", "\[Beta]f"}]], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Xi]f", " ", "is"}]}], ")"}], "\[Psi]f", " ", 
       "\[Alpha]"}]}], " ", ",", 
     RowBox[{"Un", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cn0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}], ",", 
     RowBox[{"Us", "==", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Rho]", "-", "gL"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", "cs0", "]"}], "+", 
         FractionBox["gc", 
          RowBox[{"\[Rho]", "-", "gL"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]n", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]f", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gc", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSN", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RSF", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]n0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]s0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"In0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ain0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iin0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Is0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ais0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iis0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"RDs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cn0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cs0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Un", ",", "0.1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Us", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Omega]", "\[Rule]", "5.4829984960070846`"}], ",", 
   RowBox[{"\[Psi]n", "\[Rule]", "0.058249879408689476`"}], ",", 
   RowBox[{"\[Psi]f", "\[Rule]", "0.06597250163217783`"}], ",", 
   RowBox[{"r", "\[Rule]", "0.0683304579322713`"}], ",", 
   RowBox[{"gc", "\[Rule]", "0.018330457932271293`"}], ",", 
   RowBox[{"RSN", "\[Rule]", "0.02612563799867489`"}], ",", 
   RowBox[{"RSF", "\[Rule]", "0.013266742229463207`"}], ",", 
   RowBox[{"\[Omega]n0", "\[Rule]", "0.890545894057624`"}], ",", 
   RowBox[{"\[Omega]s0", "\[Rule]", "0.1624195036176193`"}], ",", 
   RowBox[{"In0", "\[Rule]", "1.2148126809087447`"}], ",", 
   RowBox[{"ain0", "\[Rule]", "0.09384674672405943`"}], ",", 
   RowBox[{"iin0", "\[Rule]", "0.001480951407184878`"}], ",", 
   RowBox[{"RDn0", "\[Rule]", "0.1194849827775005`"}], ",", 
   RowBox[{"Is0", "\[Rule]", "1.0481979952591685`"}], ",", 
   RowBox[{"ais0", "\[Rule]", "0.02365023188446647`"}], ",", 
   RowBox[{"iis0", "\[Rule]", "0.`"}], ",", 
   RowBox[{"RDs0", "\[Rule]", "0.024547763374701888`"}], ",", 
   RowBox[{"cn0", "\[Rule]", "1.0818464450324172`"}], ",", 
   RowBox[{"cs0", "\[Rule]", "0.17024779808297782`"}], ",", 
   RowBox[{"Un", "\[Rule]", "16.673307762740095`"}], ",", 
   RowBox[{"Us", "\[Rule]", 
    RowBox[{"-", "35.26965628522425`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314565634884*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "gcfs", ",", "\[Omega]n0fs", ",", "\[Omega]s0fs", ",", "In0fs", ",", 
    "ain0fs", ",", "iin0fs", ",", "RDn0fs", ",", "Is0fs", ",", "ais0fs", ",", 
    "iis0fs", ",", "RDs0fs", ",", "cn0fs", ",", "cs0fs", ",", "Unfs", ",", 
    "Usfs"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
   "0.018330457932271293`", ",", "0.890545894057624`", ",", 
    "0.1624195036176193`", ",", "1.2148126809087447`", ",", 
    "0.09384674672405943`", ",", "0.001480951407184878`", ",", 
    "0.1194849827775005`", ",", "1.0481979952591685`", ",", 
    "0.02365023188446647`", ",", "0.`", ",", "0.024547763374701888`", ",", 
    "1.0818464450324172`", ",", "0.17024779808297782`", ",", 
    "16.673307762740095`", ",", 
    RowBox[{"-", "35.26965628522425`"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.018330457932271293`", ",", "0.890545894057624`", ",", 
   "0.1624195036176193`", ",", "1.2148126809087447`", ",", 
   "0.09384674672405943`", ",", "0.001480951407184878`", ",", 
   "0.1194849827775005`", ",", "1.0481979952591685`", ",", 
   "0.02365023188446647`", ",", "0.`", ",", "0.024547763374701888`", ",", 
   "1.0818464450324172`", ",", "0.17024779808297782`", ",", 
   "16.673307762740095`", ",", 
   RowBox[{"-", "35.26965628522425`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314565725676003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "\[CapitalDelta]gcfs", ",", "\[CapitalDelta]ln\[Omega]n0fs", ",", 
    "\[CapitalDelta]ln\[Omega]ns0fs", ",", "\[CapitalDelta]lnIn0fs", ",", 
    "\[CapitalDelta]lnIs0fs", ",", "\[CapitalDelta]lnain0fs", ",", 
    "\[CapitalDelta]lnais0fs", ",", "\[CapitalDelta]lniin0fs", ",", 
    "\[CapitalDelta]lniis0fs", ",", "\[CapitalDelta]lnRDn0fs", ",", 
    "\[CapitalDelta]lnRDs0fs", ",", "\[CapitalDelta]lncn0fs", ",", 
    "\[CapitalDelta]lncs0fs"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"gcfs", "-", "gc1"}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]n0fs", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]n01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "\[Omega]s0fs", "]"}], "-", 
       RowBox[{"Log", "[", "\[Omega]s01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "In0fs", "]"}], "-", 
       RowBox[{"Log", "[", "In01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "Is0fs", "]"}], "-", 
       RowBox[{"Log", "[", "Is01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ain0fs", "]"}], "-", 
       RowBox[{"Log", "[", "ain01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "ais0fs", "]"}], "-", 
       RowBox[{"Log", "[", "ais01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iin0fs", "]"}], "-", 
       RowBox[{"Log", "[", "iin01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "iis0fs", "]"}], "-", 
       RowBox[{"Log", "[", "iis01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDn0fs", "]"}], "-", 
       RowBox[{"Log", "[", "RDn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "RDs0fs", "]"}], "-", 
       RowBox[{"Log", "[", "RDs01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cn0fs", "]"}], "-", 
       RowBox[{"Log", "[", "cn01", "]"}]}], ")"}], "100"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", "cs0fs", "]"}], "-", 
       RowBox[{"Log", "[", "cs01", "]"}]}], ")"}], "100"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.010045793227130007`", ",", 
   RowBox[{"-", "0.04998127158434146`"}], ",", "0.12383268761255728`", ",", 
   "0.05458624427140957`", ",", 
   RowBox[{"-", "0.26874661304610237`"}], ",", "0.`", ",", 
   RowBox[{"-", "4.763851556238707`"}], ",", "0.5495455515172942`", ",", 
   "Indeterminate", ",", "0.5495455515172054`", ",", 
   RowBox[{"-", "2.9809946936371734`"}], ",", "0.004604972687061171`", ",", 
   RowBox[{"-", "0.14491392543354298`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7314565811008*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]Unfs", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Unfs"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Un1"}]}], "]"}], "-", 
     "1"}], ")"}], " ", "100"}]}]], "Input"],

Cell[BoxData["0.2872018121376385`"], "Output",
 CellChangeTimes->{3.731456590492*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]Usfs", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Usfs"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Rho]", "-", "gL"}], ")"}], " ", "Us1"}]}], "]"}], "-", 
     "1"}], ")"}], " ", "100"}]}]], "Input"],

Cell[BoxData["0.1373655377197469`"], "Output",
 CellChangeTimes->{3.7314566003668003`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.708863576922*^9, 3.7088635778892*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1860, 710},
WindowMargins->{{Automatic, -28}, {Automatic, 102}},
FrontEndVersion->"10.0 for Microsoft Windows (32-bit) (September 9, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 313, 4, 70, "Section"],
Cell[CellGroupData[{
Cell[918, 30, 338, 5, 49, "Subsection"],
Cell[CellGroupData[{
Cell[1281, 39, 102, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[1408, 44, 852, 16, 31, "Input"],
Cell[2263, 62, 322, 6, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2634, 74, 103, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[2762, 79, 2346, 62, 52, "Input"],
Cell[5111, 143, 552, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5700, 159, 328, 10, 31, "Input"],
Cell[6031, 171, 259, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6327, 181, 54900, 1298, 1104, "Input"],
Cell[61230, 1481, 243, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61510, 1491, 197, 6, 31, "Input"],
Cell[61710, 1499, 171, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61918, 1508, 11283, 289, 216, "Input"],
Cell[73204, 1799, 204, 5, 31, "Output"]
}, Open  ]],
Cell[73423, 1807, 175, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73635, 1815, 147, 2, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[73807, 1821, 13947, 400, 329, "Input"],
Cell[87757, 2223, 1419, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89213, 2254, 791, 16, 72, "Input"],
Cell[90007, 2272, 559, 11, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[90615, 2289, 118, 1, 39, "Subsubsection"],
Cell[90736, 2292, 59, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[90820, 2297, 96, 3, 31, "Input"],
Cell[90919, 2302, 110, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91066, 2309, 13947, 400, 329, "Input"],
Cell[105016, 2711, 1401, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106454, 2742, 786, 17, 72, "Input"],
Cell[107243, 2761, 537, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107817, 2777, 2513, 72, 72, "Input"],
Cell[110333, 2851, 486, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110856, 2864, 115, 3, 31, "Input"],
Cell[110974, 2869, 129, 2, 31, "Output"]
}, Open  ]],
Cell[111118, 2874, 59, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[111202, 2879, 96, 3, 31, "Input"],
Cell[111301, 2884, 114, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111452, 2891, 13947, 400, 329, "Input"],
Cell[125402, 3293, 1403, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126842, 3324, 788, 17, 72, "Input"],
Cell[127633, 3343, 538, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128208, 3359, 2513, 72, 72, "Input"],
Cell[130724, 3433, 497, 10, 31, "Output"]
}, Open  ]],
Cell[131236, 3446, 118, 2, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[131403, 3454, 134, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[131562, 3459, 295, 4, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[131882, 3467, 634, 14, 31, "Input"],
Cell[132519, 3483, 416, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132972, 3496, 1376, 42, 52, "Input"],
Cell[134351, 3540, 366, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134754, 3552, 273, 7, 31, "Input"],
Cell[135030, 3561, 229, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135296, 3571, 247, 7, 31, "Input"],
Cell[135546, 3580, 202, 5, 31, "Output"]
}, Open  ]],
Cell[135763, 3588, 118, 2, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135918, 3595, 113, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[136056, 3600, 551, 12, 31, "Input"],
Cell[136610, 3614, 353, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137000, 3626, 1376, 42, 52, "Input"],
Cell[138379, 3670, 362, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138778, 3682, 273, 7, 31, "Input"],
Cell[139054, 3691, 209, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139300, 3701, 247, 7, 31, "Input"],
Cell[139550, 3710, 183, 5, 31, "Output"]
}, Open  ]],
Cell[139748, 3718, 114, 2, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[139911, 3726, 338, 8, 79, "Subsection"],
Cell[CellGroupData[{
Cell[140274, 3738, 503, 11, 31, "Input"],
Cell[140780, 3751, 319, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141136, 3762, 328, 10, 31, "Input"],
Cell[141467, 3774, 259, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141763, 3784, 247, 7, 31, "Input"],
Cell[142013, 3793, 212, 5, 31, "Output"]
}, Open  ]],
Cell[142240, 3801, 118, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[142383, 3807, 110, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[142518, 3812, 503, 11, 31, "Input"],
Cell[143024, 3825, 303, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143364, 3836, 328, 10, 31, "Input"],
Cell[143695, 3848, 231, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143963, 3858, 247, 7, 31, "Input"],
Cell[144213, 3867, 183, 5, 31, "Output"]
}, Open  ]],
Cell[144411, 3875, 112, 2, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[144572, 3883, 125, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[144722, 3888, 113, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[144860, 3893, 501, 11, 31, "Input"],
Cell[145364, 3906, 316, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145717, 3917, 328, 10, 31, "Input"],
Cell[146048, 3929, 254, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146339, 3939, 247, 7, 31, "Input"],
Cell[146589, 3948, 203, 5, 31, "Output"]
}, Open  ]],
Cell[146807, 3956, 122, 2, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146966, 3963, 107, 1, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[147098, 3968, 501, 11, 31, "Input"],
Cell[147602, 3981, 296, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147935, 3992, 328, 10, 31, "Input"],
Cell[148266, 4004, 235, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148538, 4014, 247, 7, 31, "Input"],
Cell[148788, 4023, 183, 5, 31, "Output"]
}, Open  ]],
Cell[148986, 4031, 114, 2, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[149161, 4040, 326, 8, 101, "Section"],
Cell[CellGroupData[{
Cell[149512, 4052, 413, 10, 31, "Input"],
Cell[149928, 4064, 261, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150226, 4075, 197, 6, 31, "Input"],
Cell[150426, 4083, 152, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150615, 4092, 137, 1, 41, "Subsubsection"],
Cell[CellGroupData[{
Cell[150777, 4097, 6196, 176, 149, "Input"],
Cell[156976, 4275, 750, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157763, 4293, 423, 10, 31, "Input"],
Cell[158189, 4305, 295, 6, 31, "Output"]
}, Open  ]],
Cell[158499, 4314, 89, 2, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158625, 4321, 132, 1, 41, "Subsubsection"],
Cell[CellGroupData[{
Cell[158782, 4326, 11030, 316, 283, "Input"],
Cell[169815, 4644, 1402, 25, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171254, 4674, 814, 16, 72, "Input"],
Cell[172071, 4692, 568, 11, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[172688, 4709, 157, 2, 41, "Subsubsection"],
Cell[172848, 4713, 59, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[172932, 4718, 96, 3, 31, "Input"],
Cell[173031, 4723, 94, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173162, 4730, 11030, 316, 283, "Input"],
Cell[184195, 5048, 1400, 25, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185632, 5078, 813, 17, 72, "Input"],
Cell[186448, 5097, 553, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187038, 5113, 2636, 76, 72, "Input"],
Cell[189677, 5191, 542, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190256, 5207, 398, 13, 31, "Input"],
Cell[190657, 5222, 86, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190780, 5228, 398, 13, 31, "Input"],
Cell[191181, 5243, 88, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191306, 5249, 115, 3, 31, "Input"],
Cell[191424, 5254, 109, 2, 31, "Output"]
}, Open  ]],
Cell[191548, 5259, 59, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[191632, 5264, 96, 3, 31, "Input"],
Cell[191731, 5269, 90, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191858, 5276, 11030, 316, 283, "Input"],
Cell[202891, 5594, 1398, 25, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204326, 5624, 814, 17, 72, "Input"],
Cell[205143, 5643, 554, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205734, 5659, 2636, 76, 72, "Input"],
Cell[208373, 5737, 546, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208956, 5752, 398, 13, 31, "Input"],
Cell[209357, 5767, 85, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209479, 5773, 398, 13, 31, "Input"],
Cell[209880, 5788, 90, 1, 31, "Output"]
}, Open  ]],
Cell[209985, 5792, 113, 2, 31, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
